package fr.iut.pm.movieapplication.ui.adapter

import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.core.net.toUri
import androidx.recyclerview.widget.RecyclerView
import coil.load
import fr.iut.pm.movieapplication.R
import fr.iut.pm.movieapplication.model.media.movie.Movie
import fr.iut.pm.movieapplication.model.media.tvshow.TvShow
import fr.iut.pm.movieapplication.ui.activity.MainActivity
import fr.iut.pm.movieapplication.utils.Constants.Companion.IMG_URL

class CategoryAdapter<T>(
    private val context: MainActivity,
    private val layoutId: Int,
    private val list: List<T>
) : RecyclerView.Adapter<MediaAdapter.ViewHolder>(){

    class ViewHolder(view : View) : RecyclerView.ViewHolder(view) {
        val itemImage: ImageView = view.findViewById<ImageView>(R.id.item_image)
        val itemName: TextView = view.findViewById<TextView>(R.id.item_name)
        val itemDate: TextView = view.findViewById<TextView>(R.id.item_date)
    }


    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): MediaAdapter.ViewHolder {
        val view = LayoutInflater
            .from(parent.context)
            .inflate(layoutId, parent, false)
        return MediaAdapter.ViewHolder(view)
    }

    override fun getItemCount(): Int = list.size


    override fun onBindViewHolder(holder: MediaAdapter.ViewHolder, position: Int) {
        val currentItem = list[position]
        if(currentItem != null) {

            when(currentItem!!::class.java) {
                Movie::class.java -> bindMovie(holder, currentItem as Movie)
                TvShow::class.java -> bindTvShow(holder, currentItem as TvShow)
            }

        }
    }

    private fun bindTvShow(holder: MediaAdapter.ViewHolder, tvShow: TvShow) {
        val imgUri = tvShow.posterPath?.let { (IMG_URL+it).toUri().buildUpon().scheme("https").build() }
        holder.itemImage.load(imgUri)
        holder.itemName.text = tvShow.name
        holder.itemDate.text = tvShow.firstAirDate
    }

    private fun bindMovie(holder: MediaAdapter.ViewHolder, movie: Movie) {
        val imgUri = movie.posterPath?.let { (IMG_URL+it).toUri().buildUpon().scheme("https").build() }
        holder.itemImage.load(imgUri)
        holder.itemName.text = movie.title
        holder.itemDate.text = movie.releaseDate
    }

    private fun onItemClick(item : Movie) {
        Log.d("item clicked", item.toString())
    }
}